package com.ruoyi.ems.service.impl;

import java.util.List;

import com.ruoyi.ems.domain.ElecEqptType;
import com.ruoyi.ems.mapper.EleceqptTypeMapper;
import com.ruoyi.ems.service.IElecEqptTypeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 动力柜电器设备类型Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-08-20
 */
@Service
public class ElecEqptTypeServiceImpl implements IElecEqptTypeService
{
    @Autowired
    private EleceqptTypeMapper elecEqptTypeMapper;

    /**
     * 查询动力柜电器设备类型
     * 
     * @param id 动力柜电器设备类型主键
     * @return 动力柜电器设备类型
     */
    @Override
    public ElecEqptType selectElecEqptTypeById(Long id)
    {
        return elecEqptTypeMapper.selectElecEqptTypeById(id);
    }

    /**
     * 查询动力柜电器设备类型列表
     * 
     * @param eleceqptType 动力柜电器设备类型
     * @return 动力柜电器设备类型
     */
    @Override
    public List<ElecEqptType> selectElecEqptTypeList(ElecEqptType eleceqptType)
    {
        return elecEqptTypeMapper.selectElecEqptTypeList(eleceqptType);
    }

    /**
     * 新增动力柜电器设备类型
     * 
     * @param eleceqptType 动力柜电器设备类型
     * @return 结果
     */
    @Override
    public int insertElecEqptType(ElecEqptType eleceqptType)
    {
        return elecEqptTypeMapper.insertElecEqptType(eleceqptType);
    }

    /**
     * 修改动力柜电器设备类型
     * 
     * @param eleceqptType 动力柜电器设备类型
     * @return 结果
     */
    @Override
    public int updateElecEqptType(ElecEqptType eleceqptType)
    {
        return elecEqptTypeMapper.updateElecEqptType(eleceqptType);
    }

    /**
     * 批量删除动力柜电器设备类型
     * 
     * @param ids 需要删除的动力柜电器设备类型主键
     * @return 结果
     */
    @Override
    public int deleteElecEqptTypeByIds(Long[] ids)
    {
        return elecEqptTypeMapper.deleteElecEqptTypeByIds(ids);
    }

    /**
     * 删除动力柜电器设备类型信息
     * 
     * @param id 动力柜电器设备类型主键
     * @return 结果
     */
    @Override
    public int deleteElecEqptTypeById(Long id)
    {
        return elecEqptTypeMapper.deleteElecEqptTypeById(id);
    }
}
